==> package-manager-1.99.1.tar.gz: package-manager-1.99.1/setup/parse-options.h <==
#ifndef _PARSE_OPTIONS_H
#define _PARSE_OPTIONS_H

/* === Constants for the action field into stSetupOptions === */
#define ACTION_UNKNOWN		0
#define ACTION_INSTALL		1
#define ACTION_FINALIZE		2
#define ACTION_POSTINSTALL	3
#define ACTION_XPOSTINSTALL	4
#define ACTION_UPDATE		5
#define ACTION_RESTORE		6
#define ACTION_DELETE		7
#define ACTION_REMOVE		7
#define ACTION_PURGE		8
#define ACTION_CLEANUP		8
#define ACTION_CHECK		9
#define ACTION_MD5CHECK		10
#define ACTION_REQUEST		11
#define ACTION_TEST		12
#define ACTION_LIST		13
#define ACTION_INFO		14
#define ACTION_UPGRADE		15

/* === Structure to hold the user options === */

typedef struct stSetupOptions TSetupOptions;

struct stSetupOptions {
  // Source Option
  char *sourcefile;	// full filename of the source package
  char *targetdir;	// rootdir of the installation
  char *tempdir;	// temporary dir for package header 
                        // ( targetdir + DEFAULT_TEMPROOT + random )
  char *tempscript;	// $tempdir + /install/scripts
  char *spoolroot;	// fullname of the spool directory
  char *spooldir;	// $SPOOLROOT + $FULLNAME

  // Action Option
  int   action;		// Action to be performed
  int	noheader;	// if 1 don't print program banner
  int   debug;		// Debug flag (show many info if 1)
  int   interactive;	// 0=remote (from floppy)  1=interactive (from root)
  int   verbose;	// Verbosing level
  int	relaxed;	// use the fear  (always escape)

#ifdef TODO
  char *sourcedir;	// dirname of the source package
  char *sourceext;	// extension of the package
  char *soname;		// name of the package with no version
  char *version;	// version of the package
  char *fullname;	// $SONAME e $VERSION separated by '_'
  // Action Option
  int	force;		// use the forse (always continue)
#endif
};

/* Exports */
int parse_options( int *lpi, char ***lpac);
int debug_options();
extern TSetupOptions gostOptions;

#endif

==> package-manager-1.99.4.tar.gz: package-manager-1.99.4/setup/parse-options.h <==
#ifndef _PARSE_OPTIONS_H
#define _PARSE_OPTIONS_H

/* === Constants for the action field into stSetupOptions === */
#define ACTION_UNKNOWN		0
#define ACTION_INSTALL		1
#define ACTION_FINALIZE		2
#define ACTION_POSTINSTALL	3
#define ACTION_XPOSTINSTALL	4
#define ACTION_UPDATE		5
#define ACTION_RESTORE		6
#define ACTION_DELETE		7
#define ACTION_REMOVE		7
#define ACTION_PURGE		8
#define ACTION_CLEANUP		8
#define ACTION_CHECK		9
#define ACTION_MD5CHECK		10
#define ACTION_REQUEST		11
#define ACTION_TEST		12
#define ACTION_LIST		13
#define ACTION_INFO		14
#define ACTION_UPGRADE		15

/* === Structure to hold the user options === */

typedef struct stSetupOptions TSetupOptions;

struct stSetupOptions {
  // Source Option
  char *sourcefile;	// full filename of the source package
  char *targetdir;	// rootdir of the installation
  char *tempdir;	// temporary dir for package header 
                        // ( targetdir + DEFAULT_TEMPROOT + random )
  char *tempscript;	// $tempdir + /install/scripts
  char *spoolroot;	// fullname of the spool directory
  char *spooldir;	// $SPOOLROOT + $FULLNAME

  // Action Option
  int   action;		// Action to be performed
  int	noheader;	// if 1 don't print program banner
  int   debug;		// Debug flag (show many info if 1)
  int   interactive;	// 0=remote (from floppy or cdrom)  1=interactive (from root)
  int   verbose;	// Verbosing level
  int	relaxed;	// use the fear  (always escape)
  int   nodeps;         // do not call setup_request(...) but schedule them
  int   force;          // overwrite existing package
  
#ifdef TODO
  char *sourcedir;	// dirname of the source package
  char *sourceext;	// extension of the package
  char *soname;		// name of the package with no version
  char *version;	// version of the package
  char *fullname;	// $SONAME e $VERSION separated by '_'
  // Action Option
  int	force;		// use the forse (always continue)
#endif
};

/* Exports */
int parse_options( int *lpi, char ***lpac);
int debug_options();
extern TSetupOptions gostOptions;

#endif
